@@ -269,7 +269,8 @@ SEXP cairo_create_new_device(SEXP args)
 	    error("unable to start device %s", devname);
 	}
 	
-	gsetVar(install(".Device"), mkString(devname), R_NilValue);
+	gsetVar(PROTECT(install(".Device")), PROTECT(mkString(devname)), R_NilValue);
+	UNPROTECT(2);
 	dd = GEcreateDevDesc(dev);
 	GEaddDevice(dd);
 	GEinitDisplayList(dd);
@@ -389,15 +390,16 @@ SEXP cairo_font_match(SEXP args){
 					FcChar8 *fname;
 
 					fname = FcNameUnparse(fs->fonts[j]);
-					if (fname){
-						vpat = FcNameParse(fname);
-						FcPatternDel(vpat,FC_CHARSET);
-						FcPatternDel(vpat,FC_LANG);
-						free(fname);
-						fname = FcNameUnparse(vpat);
+					if (fname) {
+						if ((vpat = FcNameParse(fname))) {
+							FcPatternDel(vpat,FC_CHARSET);
+							FcPatternDel(vpat,FC_LANG);
+							free(fname);
+							fname = FcNameUnparse(vpat);
+						}
 						Rprintf("   \"%s\"\n",fname);
 						free(fname);
-						FcPatternDestroy (vpat);
+						FcPatternDestroy(vpat);
 					}
 				}
 			}
